@@ -49,6 +49,7 @@ typedef enum {
   GDK_VULKAN_FEATURE_SEMAPHORE_IMPORT           = 1 << 3,
   GDK_VULKAN_FEATURE_INCREMENTAL_PRESENT        = 1 << 4,
   GDK_VULKAN_FEATURE_SWAPCHAIN_MAINTENANCE      = 1 << 5,
+  GDK_VULKAN_FEATURE_SWAPCHAIN_COLORSPACE       = 1 << 6,
 } GdkVulkanFeatures;
 
 #define GDK_VULKAN_N_FEATURES 6
@@ -126,7 +127,7 @@ struct _GdkDisplay
   GdkDmabufFormats *vk_dmabuf_formats;
   GdkVulkanFeatures vulkan_features;
 
-  guint vulkan_refcount;
+  GError *vulkan_error;
 #endif /* GDK_RENDERING_VULKAN */
 
   /* egl info */
@@ -239,6 +240,8 @@ void                _gdk_display_unpause_events       (GdkDisplay       *display
 
 void                gdk_display_init_dmabuf           (GdkDisplay       *self);
 
+gboolean            gdk_display_prepare_vulkan        (GdkDisplay       *self,
+                                                       GError          **error);
 gboolean            gdk_display_has_vulkan_feature    (GdkDisplay       *self,
                                                        GdkVulkanFeatures feature);
 GdkVulkanContext *  gdk_display_create_vulkan_context (GdkDisplay       *self,
@@ -297,5 +300,7 @@ void gdk_display_set_cursor_theme          (GdkDisplay   *display,
                                             const char   *name,
                                             int           size);
 
+int gdk_display_guess_scale_factor         (GdkDisplay   *display);
+
 G_END_DECLS
 
