@@ -31,6 +31,8 @@
 #include "gdkx11property.h"
 #include "gdkx11surface.h"
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+
 typedef struct _GdkX11PendingSelectionNotify GdkX11PendingSelectionNotify;
 typedef struct _GdkX11SelectionOutputStreamPrivate  GdkX11SelectionOutputStreamPrivate;
 
@@ -653,7 +655,6 @@ print_atoms (GdkDisplay *display,
              const Atom *atoms,
              gsize       n_atoms)
 {
-#ifdef G_ENABLE_DEBUG
   if (GDK_DISPLAY_DEBUG_CHECK (display, CLIPBOARD))
     {
       GString *str;
@@ -666,7 +667,6 @@ print_atoms (GdkDisplay *display,
       gdk_debug_message ("%s", str->str);
       g_string_free (str, TRUE);
     }
-#endif
 }
 
 static void
