@@ -82,6 +82,10 @@ gboolean gtk_init_check_abi_check (int     num_checks,
 
 GDK_AVAILABLE_IN_ALL
 void              gtk_disable_setlocale    (void);
+
+GDK_AVAILABLE_IN_4_18
+void              gtk_disable_portals      (void);
+
 GDK_AVAILABLE_IN_ALL
 PangoLanguage *   gtk_get_default_language (void) G_GNUC_CONST;
 GDK_AVAILABLE_IN_ALL
