@@ -24,6 +24,7 @@
 
 #include "gtkoverlaylayout.h"
 #include "gtkbuildable.h"
+#include "gtkbuilderprivate.h"
 #include "gtkmarshalers.h"
 #include "gtkprivate.h"
 #include "gtkscrolledwindow.h"
@@ -33,10 +34,12 @@
 /**
  * GtkOverlay
  *
- * `GtkOverlay` is a container which contains a single main child, on top
- * of which it can place “overlay” widgets.
+ * Places “overlay” widgets on top of a single main child.
  *
- * ![An example GtkOverlay](overlay.png)
+ * <picture>
+ *   <source srcset="overlay-dark.png" media="(prefers-color-scheme: dark)">
+ *   <img alt="An example GtkOverlay" src="overlay.png">
+ * </picture>
  *
  * The position of each overlay widget is determined by its
  * [property@Gtk.Widget:halign] and [property@Gtk.Widget:valign]
@@ -114,7 +117,8 @@ effective_align (GtkAlign         align,
       return direction == GTK_TEXT_DIR_RTL ? GTK_ALIGN_START : GTK_ALIGN_END;
     case GTK_ALIGN_FILL:
     case GTK_ALIGN_CENTER:
-    case GTK_ALIGN_BASELINE:
+    case GTK_ALIGN_BASELINE_FILL:
+    case GTK_ALIGN_BASELINE_CENTER:
     default:
       return align;
     }
@@ -154,7 +158,8 @@ gtk_overlay_get_child_position (GtkOverlay    *overlay,
     case GTK_ALIGN_END:
       alloc->x += width - alloc->width;
       break;
-    case GTK_ALIGN_BASELINE:
+    case GTK_ALIGN_BASELINE_FILL:
+    case GTK_ALIGN_BASELINE_CENTER:
     default:
       g_assert_not_reached ();
       break;
@@ -177,7 +182,8 @@ gtk_overlay_get_child_position (GtkOverlay    *overlay,
     case GTK_ALIGN_END:
       alloc->y += height - alloc->height;
       break;
-    case GTK_ALIGN_BASELINE:
+    case GTK_ALIGN_BASELINE_FILL:
+    case GTK_ALIGN_BASELINE_CENTER:
     default:
       g_assert_not_reached ();
       break;
@@ -315,7 +321,7 @@ gtk_overlay_class_init (GtkOverlayClass *klass)
   klass->get_child_position = gtk_overlay_get_child_position;
 
   /**
-   * GtkOverlay:child: (attributes org.gtk.Property.get=gtk_overlay_get_child org.gtk.Property.set=gtk_overlay_set_child)
+   * GtkOverlay:child:
    *
    * The main child widget.
    */
@@ -384,11 +390,18 @@ gtk_overlay_buildable_add_child (GtkBuildable *buildable,
   if (GTK_IS_WIDGET (child))
     {
       if (type && strcmp (type, "overlay") == 0)
-        gtk_overlay_add_overlay (GTK_OVERLAY (buildable), GTK_WIDGET (child));
+        {
+          gtk_overlay_add_overlay (GTK_OVERLAY (buildable), GTK_WIDGET (child));
+        }
       else if (!type)
-        gtk_overlay_set_child (GTK_OVERLAY (buildable), GTK_WIDGET (child));
+        {
+          gtk_buildable_child_deprecation_warning (buildable, builder, NULL, "child");
+          gtk_overlay_set_child (GTK_OVERLAY (buildable), GTK_WIDGET (child));
+        }
       else
-        GTK_BUILDER_WARN_INVALID_CHILD_TYPE (buildable, type);
+        {
+          GTK_BUILDER_WARN_INVALID_CHILD_TYPE (buildable, type);
+        }
     }
   else
     {
@@ -575,7 +588,10 @@ gtk_overlay_set_child (GtkOverlay *overlay,
                        GtkWidget  *child)
 {
   g_return_if_fail (GTK_IS_OVERLAY (overlay));
-  g_return_if_fail (child == NULL || GTK_IS_WIDGET (child));
+  g_return_if_fail (child == NULL || overlay->child == child || gtk_widget_get_parent (child) == NULL);
+
+  if (overlay->child == child)
+    return;
 
   g_clear_pointer (&overlay->child, gtk_widget_unparent);
 
