@@ -21,16 +21,14 @@
 
 #include "gtkstringfilter.h"
 
-#include "gtkintl.h"
 #include "gtktypebuiltins.h"
 
 /**
  * GtkStringFilter:
  *
- * `GtkStringFilter` determines whether to include items by comparing
- * strings to a fixed search term.
+ * Determines whether to include items by comparing strings to a fixed search term.
  *
- * The strings are obtained from the items by evaluating a `GtkExpression`
+ * The strings are obtained from the items by evaluating an expression
  * set with [method@Gtk.StringFilter.set_expression], and they are
  * compared against a search term set with [method@Gtk.StringFilter.set_search].
  *
@@ -248,50 +246,43 @@ gtk_string_filter_class_init (GtkStringFilterClass *class)
   object_class->dispose = gtk_string_filter_dispose;
 
   /**
-   * GtkStringFilter:expression: (type GtkExpression) (attributes org.gtk.Property.get=gtk_string_filter_get_expression org.gtk.Property.set=gtk_string_filter_set_expression)
+   * GtkStringFilter:expression: (type GtkExpression)
    *
-   * The expression to evaluate on item to get a string to compare with.
+   * The expression to evaluate on each item to get a
+   * string to compare with.
    */
   properties[PROP_EXPRESSION] =
-    gtk_param_spec_expression ("expression",
-                               P_("Expression"),
-                               P_("Expression to compare with"),
+    gtk_param_spec_expression ("expression", NULL, NULL,
                                G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkStringFilter:ignore-case: (attributes org.gtk.Property.get=gtk_string_filter_get_ignore_case org.gtk.Property.set=gtk_string_filter_set_ignore_case)
+   * GtkStringFilter:ignore-case:
    *
    * If matching is case sensitive.
    */
   properties[PROP_IGNORE_CASE] =
-      g_param_spec_boolean ("ignore-case",
-                            P_("Ignore case"),
-                            P_("If matching is case sensitive"),
+      g_param_spec_boolean ("ignore-case", NULL, NULL,
                             TRUE,
                             G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkStringFilter:match-mode: (attributes org.gtk.Property.get=gtk_string_filter_get_match_mode org.gtk.Property.set=gtk_string_filter_set_match_mode)
+   * GtkStringFilter:match-mode:
    *
    * If exact matches are necessary or if substrings are allowed.
    */
   properties[PROP_MATCH_MODE] =
-      g_param_spec_enum ("match-mode",
-                         P_("Match mode"),
-                         P_("If exact matches are necessary or if substrings are allowed"),
+      g_param_spec_enum ("match-mode", NULL, NULL,
                          GTK_TYPE_STRING_FILTER_MATCH_MODE,
                          GTK_STRING_FILTER_MATCH_MODE_SUBSTRING,
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkStringFilter:search: (attributes org.gtk.Property.get=gtk_string_filter_get_search org.gtk.Property.set=gtk_string_filter_set_search)
+   * GtkStringFilter:search:
    *
    * The search term.
    */
   properties[PROP_SEARCH] =
-      g_param_spec_string ("search",
-                           P_("Search"),
-                           P_("The search term"),
+      g_param_spec_string ("search", NULL, NULL,
                            NULL,
                            G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
@@ -308,7 +299,7 @@ gtk_string_filter_init (GtkStringFilter *self)
 
 /**
  * gtk_string_filter_new:
- * @expression: (transfer full) (nullable): The expression to evaluate
+ * @expression: (transfer full) (nullable): the expression to evaluate
  *
  * Creates a new string filter.
  *
@@ -332,12 +323,12 @@ gtk_string_filter_new (GtkExpression *expression)
 }
 
 /**
- * gtk_string_filter_get_search: (attributes org.gtk.Method.get_property=search)
- * @self: a `GtkStringFilter`
+ * gtk_string_filter_get_search:
+ * @self: a string filter
  *
  * Gets the search term.
  *
- * Returns: (nullable) (transfer none): The search term
+ * Returns: (nullable) (transfer none): the search term
  **/
 const char *
 gtk_string_filter_get_search (GtkStringFilter *self)
@@ -348,10 +339,9 @@ gtk_string_filter_get_search (GtkStringFilter *self)
 }
 
 /**
- * gtk_string_filter_set_search: (attributes org.gtk.Method.set_property=search)
- * @self: a `GtkStringFilter`
- * @search: (transfer none) (nullable): The string to search for
- *   or %NULL to clear the search
+ * gtk_string_filter_set_search:
+ * @self: a string filter
+ * @search: (transfer none) (nullable): the string to search for
  *
  * Sets the string to search for.
  */
@@ -389,13 +379,13 @@ gtk_string_filter_set_search (GtkStringFilter *self,
 }
 
 /**
- * gtk_string_filter_get_expression: (attributes org.gtk.Method.get_property=expression)
- * @self: a `GtkStringFilter`
+ * gtk_string_filter_get_expression:
+ * @self: a string filter
  *
  * Gets the expression that the string filter uses to
  * obtain strings from items.
  *
- * Returns: (transfer none) (nullable): a `GtkExpression`
+ * Returns: (transfer none) (nullable): the expression 
  */
 GtkExpression *
 gtk_string_filter_get_expression (GtkStringFilter *self)
@@ -406,14 +396,14 @@ gtk_string_filter_get_expression (GtkStringFilter *self)
 }
 
 /**
- * gtk_string_filter_set_expression: (attributes org.gtk.Method.set_property=expression)
- * @self: a `GtkStringFilter`
- * @expression: (nullable): a `GtkExpression`
+ * gtk_string_filter_set_expression:
+ * @self: a string filter
+ * @expression: (nullable): the expression
  *
  * Sets the expression that the string filter uses to
  * obtain strings from items.
  *
- * The expression must have a value type of %G_TYPE_STRING.
+ * The expression must have a value type of `G_TYPE_STRING`.
  */
 void
 gtk_string_filter_set_expression (GtkStringFilter *self,
@@ -435,12 +425,12 @@ gtk_string_filter_set_expression (GtkStringFilter *self,
 }
 
 /**
- * gtk_string_filter_get_ignore_case: (attributes org.gtk.Method.get_property=ignore-case)
- * @self: a `GtkStringFilter`
+ * gtk_string_filter_get_ignore_case:
+ * @self: a string filter
  *
  * Returns whether the filter ignores case differences.
  *
- * Returns: %TRUE if the filter ignores case
+ * Returns: true if the filter ignores case
  */
 gboolean
 gtk_string_filter_get_ignore_case (GtkStringFilter *self)
@@ -451,9 +441,9 @@ gtk_string_filter_get_ignore_case (GtkStringFilter *self)
 }
 
 /**
- * gtk_string_filter_set_ignore_case: (attributes org.gtk.Method.set_property=ignore-case)
- * @self: a `GtkStringFilter`
- * @ignore_case: %TRUE to ignore case
+ * gtk_string_filter_set_ignore_case:
+ * @self: a string filter
+ * @ignore_case: true to ignore case
  *
  * Sets whether the filter ignores case differences.
  */
@@ -479,8 +469,8 @@ gtk_string_filter_set_ignore_case (GtkStringFilter *self,
 }
 
 /**
- * gtk_string_filter_get_match_mode: (attributes org.gtk.Method.get_property=match-mode)
- * @self: a `GtkStringFilter`
+ * gtk_string_filter_get_match_mode:
+ * @self: a string filter
  *
  * Returns the match mode that the filter is using.
  *
@@ -495,8 +485,8 @@ gtk_string_filter_get_match_mode (GtkStringFilter *self)
 }
 
 /**
- * gtk_string_filter_set_match_mode: (attributes org.gtk.Method.set_property=match-mode)
- * @self: a `GtkStringFilter`
+ * gtk_string_filter_set_match_mode:
+ * @self: a string filter
  * @mode: the new match mode
  *
  * Sets the match mode for the filter.
