@@ -24,13 +24,15 @@
 #include "gtkdialogerror.h"
 #include "gtkopenuriportal.h"
 #include "deprecated/gtkshow.h"
+#include "gtkprivate.h"
 #include <glib/gi18n-lib.h>
 
 /**
  * GtkUriLauncher:
  *
- * A `GtkUriLauncher` object collects the arguments that are needed to open a uri
- * with an application.
+ * Asynchronous API to open a uri with an application.
+ *
+ * `GtkUriLauncher` collects the arguments that are needed to open the uri.
  *
  * Depending on system configuration, user preferences and available APIs, this
  * may or may not show an app chooser dialog or launch the default application
@@ -167,7 +169,7 @@ gtk_uri_launcher_new (const char *uri)
 
 /**
  * gtk_uri_launcher_get_uri:
- * @self: a `GtkUriLauncher`
+ * @self: an uri launcher
  *
  * Gets the uri that will be opened.
  *
@@ -185,7 +187,7 @@ gtk_uri_launcher_get_uri (GtkUriLauncher *self)
 
 /**
  * gtk_uri_launcher_set_uri:
- * @self: a `GtkUriLauncher`
+ * @self: an uri launcher
  * @uri: (nullable): the uri
  *
  * Sets the uri that will be opened.
@@ -258,14 +260,14 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 
 /**
  * gtk_uri_launcher_launch:
- * @self: a `GtkUriLauncher`
- * @parent: (nullable): the parent `GtkWindow`
- * @cancellable: (nullable): a `GCancellable` to cancel the operation
+ * @self: an uri launcher
+ * @parent: (nullable): the parent window
+ * @cancellable: (nullable): a cancellable to cancel the operation
  * @callback: (scope async) (closure user_data): a callback to call when the
  *   operation is complete
  * @user_data: data to pass to @callback
  *
- * Launch an application to open the uri.
+ * Launches an application to open the uri.
  *
  * This may present an app chooser dialog to the user.
  *
@@ -279,6 +281,9 @@ gtk_uri_launcher_launch (GtkUriLauncher      *self,
                          gpointer             user_data)
 {
   GTask *task;
+#ifndef G_OS_WIN32
+  GdkDisplay *display;
+#endif
   GError *error = NULL;
 
   g_return_if_fail (GTK_IS_URI_LAUNCHER (self));
@@ -307,8 +312,15 @@ gtk_uri_launcher_launch (GtkUriLauncher      *self,
     }
 
 #ifndef G_OS_WIN32
-  if (gtk_openuri_portal_is_available ())
-    gtk_openuri_portal_open_uri_async (self->uri, parent, cancellable, open_done, task);
+  if (parent)
+    display = gtk_widget_get_display (GTK_WIDGET (parent));
+  else
+    display = gdk_display_get_default ();
+
+  if (gdk_display_should_use_portal (display, PORTAL_OPENURI_INTERFACE, 3))
+    {
+      gtk_openuri_portal_open_uri_async (self->uri, parent, cancellable, open_done, task);
+    }
   else
 #endif
     {
@@ -320,15 +332,14 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 
 /**
  * gtk_uri_launcher_launch_finish:
- * @self: a `GtkUriLauncher`
- * @result: a `GAsyncResult`
+ * @self: an uri launcher
+ * @result: the result
  * @error: return location for a [enum@Gtk.DialogError] or [enum@Gio.Error] error
  *
  * Finishes the [method@Gtk.UriLauncher.launch] call and
  * returns the result.
  *
- * Returns: `TRUE` if an application was launched,
- *     or `FALSE` and @error is set
+ * Returns: true if an application was launched
  *
  * Since: 4.10
  */
