@@ -469,7 +469,7 @@ log_writer (GLogLevelFlags   log_level,
             gsize            n_fields,
             gpointer         user_data)
 {
-#ifndef G_OS_WIN32
+#if !defined (G_OS_WIN32) && !defined (__ANDROID__)
   if (log_level & G_LOG_LEVEL_CRITICAL)
     {
       void *buffer[1024];
@@ -507,7 +507,7 @@ log_writer (GLogLevelFlags   log_level,
     }
 #endif
 
- if (!would_drop (log_level, NULL))
+  if (!would_drop (log_level, NULL))
     return g_log_writer_standard_streams (log_level, fields, n_fields, user_data);
 
   return G_LOG_WRITER_HANDLED;
@@ -561,15 +561,10 @@ main (int argc, char **argv)
   /* We need to ensure the process' current working directory
    * is the same as the reftest data, because we're using the
    * "file" property of GtkImage as a relative path in builder files.
-   *
-   * The g_assert() is needed to ensure GNU libc does not complain
-   * about the unused return value, and the G_GNUC_UNUSED is needed
-   * to avoid compiler warnings when g_assert() is compiled out
-   * during the release build.
    */
-  int res G_GNUC_UNUSED;
+  int res;
   res = chdir (basedir);
-  g_assert (res == 0);
+  g_assert_true (res == 0);
 
   g_log_set_writer_func (log_writer, NULL, NULL);
 
